@@ -1,5 +1,5 @@
 package Algorithm::QuadTree;
-$Algorithm::QuadTree::VERSION = '0.4';
+$Algorithm::QuadTree::VERSION = '0.5';
 use strict;
 use warnings;
 use Carp;
@@ -101,16 +101,6 @@ sub add
 	@coords = $self->_adjustCoords(@coords)
 		unless $self->{SCALE} == 1;
 
-	# if the object is rectangular, make sure the lower coordinate is always
-	# the first one
-	if (@coords == 4) {
-		($coords[0], $coords[2]) = ($coords[2], $coords[0])
-			if $coords[2] < $coords[0];
-
-		($coords[1], $coords[3]) = ($coords[3], $coords[1])
-			if $coords[3] < $coords[1];
-	}
-
 	_AQT_addObject($self, $object, @coords);
 
 	return;
@@ -390,7 +380,7 @@ By default, the module uses L<Algorithm::QuadTree::PP>, which is the pure perl b
 
 If you install L<Algorithm::QuadTree::XS>, the module will load and use that
 instead. This behavior can be controlled by setting
-L<ALGORITHM_QUADTREE_BACKEND> environmental variable to the package name, which
+I<ALGORITHM_QUADTREE_BACKEND> environmental variable to the package name, which
 should be used as the backend.
 
 I<Note: the environmental variable must be present before loading Algorithm::QuadTree for the first time>
